Define richness color scale which is colour-vision deficient and colour-blind people safe based on scientific colour maps by Fabio Crameri
Source:R/plotting_functions.R
color_richness.RdDefine richness color scale which is colour-vision deficient and colour-blind people safe based on scientific colour maps by Fabio Crameri
Arguments
- n
corresponds to the colorRampPalette parameter
Value
returns a colorRampPalette function with the gen3sis richness colors