Plot the richness of the given list of species on a space
Source:R/plotting_functions.R
plot_richness.RdPlot the richness of the given list of species on a space
Examples
library(gen3sis2)
all_species <- readRDS(system.file(
"extdata/SouthAmerica/species_and_spaces/species_t_2.rds",
package = "gen3sis2"
))
space <- readRDS(system.file(
"extdata/SouthAmerica/species_and_spaces/space_t_2.rds",
package = "gen3sis2"
))
plot_richness(all_species, space)