This function can be called within the observer function to save the species abundances.
Source:R/observations.R
save_abundance.RdThis function can be called within the observer function to save the species abundances.
R/observations.R
save_abundance.RdThis function can be called within the observer function to save the species abundances.