This function can be called within the observer function to save the compressed species divergence.
Source:R/observations.R
save_divergence.RdThis function can be called within the observer function to save the compressed species divergence.