This function can be called within the observer function to save the current occupancy pattern
Source:R/observations.R
save_occupancy.RdThis function can be called within the observer function to save the current occupancy pattern
R/observations.R
save_occupancy.RdThis function can be called within the observer function to save the current occupancy pattern