Skip to contents

This function can be called within the observer function to save the current richness pattern

Usage

save_richness()

Value

no return value, called for side effects

See also

Examples

if (FALSE) { # \dontrun{
  ## save the current richness pattern from within observer for each species
  # this functions should be called inside the end_of_timestep_observer function at the config file:
  save_richness()
} # }