Skip to contents

This function can be called within the observer function to save the current space, can be called independently by the user and is called by other observer functions relying on the space to be present (e.g. save_species)

Usage

save_space()

Value

no return value, called for side effects

See also

Examples

if (FALSE) { # \dontrun{
  ## save space from within observer for each species
  # this functions should be called inside the end_of_timestep_observer function at the config file:
  save_space()
} # }