Skip to contents

This function can be called within the observer function to save the species traits.

Usage

save_traits()

Value

no return value, called for side effects

See also

Examples

if (FALSE) { # \dontrun{
  ## save the current traits pattern from within observer for each population of each species
  # this functions should be called inside the end_of_timestep_observer function at the config file:
  save_traits()
} # }