Allows defining the function that changes the values of traits of a given species at each time-step and in each site. If no operations are provided, traits are not changing
Source:R/evolution.R
apply_trait_evolution.RdAllows defining the function that changes the values of traits of a given species at each time-step and in each site. If no operations are provided, traits are not changing