Plot the outline of a given space over time
Examples
library(gen3sis2)
spaces <- readRDS(system.file("extdata/SouthAmerica/space/spaces.rds", package="gen3sis2"))
plot_space_overview(spaces)
Plot the outline of a given space over time
library(gen3sis2)
spaces <- readRDS(system.file("extdata/SouthAmerica/space/spaces.rds", package="gen3sis2"))
plot_space_overview(spaces)