Checks if the necessary directories exist, and otherwise creates them
Source:R/config_handling.R
prepare_directories.RdChecks if the necessary directories exist, and otherwise creates them
Details
This function will be called by the simulation, but is made available if the directories should be created manually beforehand, for example to redirect the stdout to a file in the output directory.
Examples
if (FALSE) { # \dontrun{
# this is an internal function used to attribute directories by deduction
# called at the start of a simulation run
prepare_directories(
config_file = "./any/config.R", # must be provided
input_directory = "./any/space/dir/", # if NA, will be derived from config_file
output_directory = "./any/output/dir" # if NA, will be derived from config_file
)
} # }