This function can be called within the observer function to save the current phylogeny.
Source:R/observations.R
save_phylogeny.RdThis function can be called within the observer function to save the current phylogeny.
R/observations.R
save_phylogeny.RdThis function can be called within the observer function to save the current phylogeny.