This function can be called within the observer function to save the current richness pattern
Source:R/observations.R
save_richness.RdThis function can be called within the observer function to save the current richness pattern
R/observations.R
save_richness.RdThis function can be called within the observer function to save the current richness pattern