This function can be called within the observer function to save the current space, can be called independently by the user and is called by other observer functions relying on the space to be present (e.g. save_species)
Source:R/observations.R
save_space.RdThis function can be called within the observer function to save the current space, can be called independently by the user and is called by other observer functions relying on the space to be present (e.g. save_species)