This function can be called within the observer function to save the species traits.
Source:R/observations.R
save_traits.RdThis function can be called within the observer function to save the species traits.
R/observations.R
save_traits.RdThis function can be called within the observer function to save the species traits.